##Beta regression comparing percent MOB within chironomus larvae
##Code supports analysis for
  #Child AW, Moore BC. 2015. 
  #Effects of hypolimnetic oxygenation on the dietary consumption of methane-oxidizing bacteria by Chironomus larvae in dimictic mesotrophic lakes. 
  #Freshwater Science 34: 1293-1303. https://doi.org/10.1086/683242

#begin code
#set working dir and call data below

data=read.csv(file="betareg_winter_chir.csv", header=TRUE, sep =",")
mob=data$mob_per
lake=data$lake

library(betareg)
mob.betareg=betareg(mob~lake)
summary(mob.betareg)

library(lmtest)
coeftest(mob.betareg)

#compile figure using ggplot

library(ggplot2)
quartz(w=6,h=6)
ggplot(data,aes(factor(lake),mob_per))+
#add boxplot as a feature
geom_boxplot()+
#set limits and breaks in y axis
scale_y_continuous(limits=c(0,1),breaks=c(0,0.2,0.4,0.6,0.8,1.0))+
#set x axis labels
	xlab("")+
#set y axis labels
	ylab("Proportion dietary MOB consumption")+
#format text-can switch grey to bw for black and white
	theme_bw(base_size=15,base_family="Helvetica")+
#add letter groupings for significant differences
	annotate("text",x=1,y=0.9,label="A")+
	annotate("text",x=2,y=0.65,label="A")+
	annotate("text",x=3,y=0.4,label="B")+
#hide the gridlines
	theme(panel.grid.major=element_blank(),
		  panel.grid.minor=element_blank())+
#get rid of border
	theme(panel.border=element_blank())+
#put the axes back on
	theme(axis.line=element_line())

ggsave("Figure6.tiff",height=6,width=6,dpi=300)

#End Code--Results are below

Call:
betareg(formula = mob ~ lake)

Standardized weighted residuals 2:
    Min      1Q  Median      3Q     Max 
-4.1031 -0.0973  0.0136  0.1630  5.4186 

Coefficients (mean model with logit link):
            Estimate Std. Error z value Pr(>|z|)    
(Intercept)  0.06518    0.09531   0.684   0.4941    
lakeNT      -0.25826    0.13841  -1.866   0.0621 .  
lakeST      -0.90458    0.10369  -8.724   <2e-16 ***

Phi coefficients (precision model with identity link):
      Estimate Std. Error z value Pr(>|z|)    
(phi)   39.052      5.693   6.859 6.93e-12 ***
---
Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 

Type of estimator: ML (maximum likelihood)
Log-likelihood: 109.6 on 4 Df
Pseudo R-squared: 0.5149
Number of iterations: 21 (BFGS) + 2 (Fisher scoring) 


> coeftest(mob.betareg)

z test of coefficients:

             Estimate Std. Error z value  Pr(>|z|)    
(Intercept)  0.065180   0.095313  0.6839   0.49407    
lakeNT      -0.258255   0.138408 -1.8659   0.06206 .  
lakeST      -0.904577   0.103688 -8.7240 < 2.2e-16 ***
(phi)       39.051582   5.693423  6.8591 6.931e-12 ***
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1