#Boxplot function to create boxplots with time integration

#Authors: Andrew W. Child
#Version Date: March 14, 2014

#Version 2.1 (now with ggsave-sleek)

#Data needs to be constructed in a csv file with months feb 2012 to mar 2013
#numbered from 2 to 15.  Need one column to be corrected d13C with na in unsampled months.
#month numbers in the month column.

#Begin code: 
setwd("")

#Begin function: 
box.fun<-function(csvname,lake.title,out.tiff) {
csvdata<-read.csv(csvname,
				header=T,
				na.string=c("","NA","-","<DL","na"))

#activate ggplot from library
library(ggplot2)
#untoggle to preview and toggle ggsave
#quartz(w=10,h=6)
ggplot(csvdata, aes(factor(Month), corr_d13C)) + 
#add boxplot as a feature
geom_boxplot()+
#add median points and connecting line 
stat_summary(fun.y=median, geom="line", aes(group=1))  + 
stat_summary(fun.y=median, geom="point")+
#set limits and breaks on yaxis
scale_y_continuous(limits=c(-30,0),breaks=c(-30,-25,-20,-15,-10,-5,0))+
#set order of groupins on x axis
	scale_x_discrete(breaks=c(3,4,5,6,7,8,9,10,11,12,13,14,15),labels=c("Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec","Jan","Feb","Mar"))+
#set x axis labels
	xlab("")+
#set y axis labels
	ylab(expression(paste("Corrected larval ",delta^{13},"C (\u2030)")))+
#format text-can switch grey to bw for black and white
	theme_bw(base_size=15,base_family="Helvetica")+
  theme(panel.border = element_blank(), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))+
# create optional plot title in fuction code
	ggtitle(lake.title)
#toggle ggsave if you wish to only preview your boxplot	
	ggsave(out.tiff,width=10,height=6,dpi=800)
}					#End of 'box.fun'function

#Figures
  #Newman Lake
    box.fun("NEW_DEEP.csv","","Fig1b.tiff")
    dev.off()
    box.fun("NEW_SHALLOW.csv","","Fig1C.tiff")
    dev.off()
  #North Twin Lake
    box.fun("NT_DEEP.csv","","Fig2b.tiff")
    dev.off()
    box.fun("NT_SHALLOW.csv","","Fig2C.tiff")
    dev.off()
  #South Twin Lake
    box.fun("ST_DEEP.csv","","Fig3b.tiff")
    dev.off()
    box.fun("ST_SHALLOW.csv","","Fig3C.tiff")
    dev.off()