#d15n vs d13C linear regression for chironomids found at all lakes and sites

#remember to set your working directory
setwd("")

#import data for linear regression plot
n_data<-read.csv("d15n.csv",header=TRUE)
dataNEW<-read.table("consumerNEW.txt",header=TRUE)
dataNT<-read.table("consumerNT.txt",header=TRUE)
dataST<-read.table("consumerST.txt",header=TRUE)

#linear regression
p<-lm(formula=n_data$d15N~n_data$d13C)
summary(p)

#if you want to export as a tiff
	#1- un-toggle the following line
		tiff("Figure4.tiff",width=12,height=8,units="in",res=300)
	#2- toggle the dev.new line
	#3- make sure to turn the device off
	
#activate device 2x2
#dev.new(width=12,height=8)
par(mfrow=c(2,2))
par(oma=c(4,4,0,0))
par(mar=c(2,2,1,1))
par(family="Helvetica")
par(ps=15)
par(las=1)
	#plot graphs
	#linear regression of all data + regression line
	plot(n_data$d13C,n_data$d15N,xlab="",ylab="",xlim=c(-57,-23),ylim=c(-4,10),bty="l",labels=F)
	Axis(side=1,labels=FALSE)
	Axis(side=2,labels=TRUE)
	text(x=-57,y=10,"A")
	abline(p)
	
	#plot of newman chironomids
	plot(dataNEW$d13C,dataNEW$d15N,xlab="",ylab="",xlim=c(-57,-23),ylim=c(-4,10),bty="l",labels=F)
	Axis(side=1,labels=FALSE)
	Axis(side=2,labels=FALSE)
	text(x=-57,y=10,"B")
	
	#plus possible food souces-mean and std calculated from data in POM.csv and SOM.csv 
		#POM-open square
		points(x=-28.7,y=2.1,pch=0)
		arrows(x0=-28.7,y0=2.1-1.19,x1=-28.7,y1=2.1+1.19,code=3,angle=90,length=0.05)
		arrows(x0=-28.7-1.52,y0=2.1,x1=-28.7+1.52,y1=2.1,code=3,angle=90,length=0.05)
		#SOM-closed square
		points(x=-28.5,y=0.9,pch=15)
		arrows(x0=-28.5,y0=0.9-0.15,x1=-28.5,y1=0.9+0.15,code=3,angle=90,length=0.05)
		arrows(x0=-28.5-1.98,y0=0.9,x1=-28.5+1.98,y1=0.9,code=3,angle=90,length=0.05)
	# Make a key as a panel within the graph
		#Draw the rectangle
		rect(-30,6.25,-23,10)
		#add points
		points(x=-29,y=9,pch=0)
		points(x=-29,y=7.5,pch=15)
		#add the legend text
		text(x=-26,y=9,"POM")
		text(x=-26,y=7.5,"SOM")
	

	#plot of nt chironomids
	plot(dataNT$d13C,dataNT$d15N,xlab="",ylab="",xlim=c(-57,-23),ylim=c(-4,10),bty="l",labels=F)
	Axis(side=1,labels=TRUE)
	Axis(side=2,labels=TRUE)
	text(x=-57,y=10,"C")
	#plus possible food souces-mean and std calculated from data in POM.csv and SOM.csv
	  #POM-open square
		points(x=-30.9,y=5.3,pch=0)
		arrows(x0=-30.9,y0=5.3-4.25,x1=-30.9,y1=5.3+4.25,code=3,angle=90,length=0.05)
		arrows(x0=-30.9-3.06,y0=5.3,x1=-30.9+3.06,y1=5.3,code=3,angle=90,length=0.05)
		#SOM-closed square
		points(x=-30.3,y=2.8,pch=15)
		arrows(x0=-30.3,y0=2.8-0.62,x1=-30.3,y1=2.8+0.62,code=3,angle=90,length=0.05)
		arrows(x0=-30.3-2.48,y0=2.8,x1=-30.3+2.48,y1=2.8,code=3,angle=90,length=0.05)

	#plot of st chironomids
	plot(dataST$d13C,dataST$d15N,xlab="",ylab="",xlim=c(-57,-23),ylim=c(-4,10),bty="l",labels=F)
	Axis(side=1,labels=TRUE)
	Axis(side=2,labels=FALSE)
	text(x=-57,y=10,"D")
	#plus possible food souces-mean and std calculated from data in POM.csv and SOM.csv
		#POM-open square
		points(x=-32.4,y=1.3,pch=0)
		arrows(x0=-32.4,y0=1.3-3.52,x1=-32.4,y1=1.3+3.52,code=3,angle=90,length=0.05)
		arrows(x0=-32.4-4.68,y0=1.3,x1=-32.4+4.68,y1=1.3,code=3,angle=90,length=0.05)
		#SOM-closed square
		points(x=-25.8,y=2.3,pch=15)
		arrows(x0=-25.8,y0=2.3-0.56,x1=-25.8,y1=2.3+0.56,code=3,angle=90,length=0.05)
		arrows(x0=-25.8-3.72,y0=2.3,x1=-25.8+3.72,y1=2.3,code=3,angle=90,length=0.05)

	#labels for all the graphs
	title(xlab=expression(paste(delta^{13},"C (\u2030)")),outer=TRUE,line=1.5)
	title(ylab=expression(paste(delta^{15},"N (\u2030)")),outer=TRUE,line=1.5)

#turn the device off to save the file and only if you want to save the file
	dev.off()